@@ -92,6 +92,18 @@ class ApiDocWriter:
         self._package_name = package_name
         root_module = self._import(package_name)
         self.root_path = root_module.__path__[-1]
+
+        if not os.path.isdir(self.root_path):
+            # __path__ might point to editable loader, try falling back to __file__
+            self.root_path = os.path.dirname(root_module.__file__)
+
+        if not os.path.isdir(self.root_path):
+            msg = (
+                f"could not determine a valid directory for {root_module!r}, "
+                f"'{self.root_path}' is not a directory"
+            )
+            raise NotADirectoryError(msg)
+
         self.written_modules = None
 
     package_name = property(
